[llvm-commits] CVS: llvm/include/llvm/Value.h

Chris Lattner lattner at cs.uiuc.edu
Wed Feb 23 08:51:15 PST 2005



Changes in directory llvm/include/llvm:

Value.h updated: 1.70 -> 1.71
---
Log message:

Add new method.


---
Diffs of the changes:  (+7 -2)

 Value.h |    9 +++++++--
 1 files changed, 7 insertions(+), 2 deletions(-)


Index: llvm/include/llvm/Value.h
diff -u llvm/include/llvm/Value.h:1.70 llvm/include/llvm/Value.h:1.71
--- llvm/include/llvm/Value.h:1.70	Fri Feb  4 19:37:44 2005
+++ llvm/include/llvm/Value.h	Wed Feb 23 10:50:59 2005
@@ -117,9 +117,14 @@
   ///
   bool hasNUses(unsigned N) const;
 
+  /// hasNUsesOrMore - Return true if this value has N users or more.  This is
+  /// logically equivalent to getNumUses() >= N.
+  ///
+  bool hasNUsesOrMore(unsigned N) const;
+
   /// getNumUses - This method computes the number of uses of this Value.  This
   /// is a linear time operation.  Use hasOneUse or hasNUses to check for
   /// specific values.
   unsigned getNumUses() const;
 
   /// addUse/killUse - These two methods should only be used by the Use class.
@@ -117,9 +117,14 @@
   /// getNumUses - This method computes the number of uses of this Value.  This
-  /// is a linear time operation.  Use hasOneUse or hasNUses to check for
-  /// specific values.
+  /// is a linear time operation.  Use hasOneUse, hasNUses, or hasMoreThanNUses
+  /// to check for specific values.
   unsigned getNumUses() const;
 






More information about the llvm-commits mailing list